@@ -23,19 +23,20 @@ describe OAuth2::Response do
                          :status => 200,
                          :body => 'baz')
     end
+
     before do
-      OAuth2::Response.register_parser(:foobar, 'application/foo-bar') do |body|
+      described_class.register_parser(:foobar, 'application/foo-bar') do |body|
         "foobar #{body}"
       end
     end
 
     it 'adds to the content types and parsers' do
-      expect(OAuth2::Response.send(:class_variable_get, :@@parsers).keys).to include(:foobar)
-      expect(OAuth2::Response.send(:class_variable_get, :@@content_types).keys).to include('application/foo-bar')
+      expect(described_class.send(:class_variable_get, :@@parsers).keys).to include(:foobar)
+      expect(described_class.send(:class_variable_get, :@@content_types).keys).to include('application/foo-bar')
     end
 
     it 'is able to parse that content type automatically' do
-      expect(OAuth2::Response.new(response).parsed).to eq('foobar baz')
+      expect(described_class.new(response).parsed).to eq('foobar baz')
     end
   end
 
@@ -75,9 +76,9 @@ describe OAuth2::Response do
     end
   end
 
-  context 'xml parser registration' do
+  context 'with xml parser registration' do
     it 'tries to load multi_xml and use it' do
-      expect(OAuth2::Response.send(:class_variable_get, :@@parsers)[:xml]).not_to be_nil
+      expect(described_class.send(:class_variable_get, :@@parsers)[:xml]).not_to be_nil
     end
 
     it 'is able to parse xml' do
@@ -85,7 +86,7 @@ describe OAuth2::Response do
       body = '<?xml version="1.0" standalone="yes" ?><foo><bar>baz</bar></foo>'
 
       response = double('response', :headers => headers, :body => body)
-      expect(OAuth2::Response.new(response).parsed).to eq('foo' => {'bar' => 'baz'})
+      expect(described_class.new(response).parsed).to eq('foo' => {'bar' => 'baz'})
     end
   end
 end
